@@ -73,7 +73,10 @@ public:
     };
     Q_DECLARE_FLAGS(SearchPatternEditOptions, SearchPatternEditOption)
 
-    enum SearchModeType { StandardMode = 0, BalooMode = 1 };
+    enum SearchModeType {
+        StandardMode = 0,
+        BalooMode = 1,
+    };
 
     /**
      * Constructor. The parent parameter is passed to the underlying
@@ -121,13 +124,11 @@ Q_SIGNALS:
 
     void returnPressed();
 
-private Q_SLOTS:
-    void slotRadioClicked(QAbstractButton *aRBtn);
-    void slotAutoNameHack();
-    void slotRuleAdded(QWidget *widget);
-
 private:
-    void initLayout(SearchPatternEditOptions options, SearchModeType modeType);
+    MAILCOMMON_NO_EXPORT void slotRuleAdded(QWidget *widget);
+    MAILCOMMON_NO_EXPORT void slotAutoNameHack();
+    MAILCOMMON_NO_EXPORT void slotRadioClicked(QAbstractButton *aRBtn);
+    MAILCOMMON_NO_EXPORT void initLayout(SearchPatternEditOptions options, SearchModeType modeType);
     MailCommon::SearchPattern *mPattern = nullptr;
     QRadioButton *mAllRBtn = nullptr;
     QRadioButton *mAnyRBtn = nullptr;
